Patterns enum
Values
- CHECKBOX_LIST_PATTERN → const Patterns
-
const Patterns(r'- (\[ \]) (.+)') - CHECKBOX_LIST_DONE_PATTERN → const Patterns
-
const Patterns(r'- (\[x]) (.+)') - BOLD_TEXT_PATTERN → const Patterns
-
const Patterns(r'\*\*(.*?)\*\*') - HEADERS_PATTERN → const Patterns
-
const Patterns(r'(#{1,6}\s)(.*)') - CODE_PATTERN → const Patterns
-
const Patterns(r'```[\s\S]*?```') - URL_PATTERN → const Patterns
-
const Patterns(r'\[([^\]]+)\]\((https?:\/\/[^\)]+)\)(?: - (.+))?')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - pattern → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited